#
# spec file for package tut
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tut
Version:        2.0.1
Release:        1.5
Summary:        A TUI for Mastodon with vim inspired keys
License:        MIT
Group:          Productivity/Networking/Web/Frontends
URL:            https://tut.anv.nu
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging
# some modules require go 1.18+
BuildRequires:  golang(API) >= 1.18

%description
tut is a TUI for Mastodon with vim inspired keys. TUI is an acronym for text-based user interface, so tut runs in your terminal.

%prep
%autosetup -a 1

%build
%ifarch ppc64
go build \
   -mod=vendor \
   -tags extended
%else
go build \
   -mod=vendor \
   -tags extended \
   -buildmode=pie
%endif

%install
# Install the binary.
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"
install -D -m 0644 docs/man/%{name}.1 "%{buildroot}/%{_mandir}/man1/%{name}.1"
install -D -m 0644 docs/man/%{name}.5 "%{buildroot}/%{_mandir}/man5/%{name}.5"
install -D -m 0644 docs/man/%{name}.7 "%{buildroot}/%{_mandir}/man7/%{name}.7"

%files
%{_bindir}/%{name}
%license LICENSE
%doc README.md
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man5/%{name}.5%{?ext_man}
%{_mandir}/man7/%{name}.7%{?ext_man}

%changelog
* Fri Apr 14 2023 Stefan Weiberg <sweiberg@suse.com>
- add man pages
* Fri Apr 14 2023 sweiberg@suse.com
- Update to version 2.0.1:
  * 2.0.1 (#256)
  * Create FUNDING.yml
  * 2.0.0 (#253)
  * 1.0.34 (#243)
  * update man for 1.0.33
  * 1.0.33 (#242)
  * 1.0.32 (#240)
  * 1.0.31 (#238)
  * fix man
  * Fix documentation
* Tue Nov 29 2022 sweiberg@suse.com
- Update to version 1.0.24:
  * The config option tag-follow works now
- Update to version 1.0.23:
  * List of followed tags. Use :tags
  * Multiple tags in one feed. Use :tag linux mastodon
  * Two new flags --config and --config-dir if you want to load
    your configuration from a custom location. You can also use
    the environment variables TUT_CONF and TUT_CONF_DIR instead
  * :timeline direct shouldn't crash tut
  * :user should now find more accounts
- Update to version 1.0.22:
  * Tut won't crash when you edit a reply
* Fri Nov 25 2022 sweiberg@suse.com
- Update to version 1.0.21:
  * edit toots (#188)
* Wed Nov 23 2022 sweiberg@suse.com
- Update to version 1.0.20:
  * 1.0.20 (#183)
    You can now follow and unfollow tags with :follow-tag tut and
    :unfollow-tag tut.
    You can now add and remove users from lists. Run :lists and
    then you can use the keys that tut displays. This feature only
    works okay as it doesn't give you any response if the user is
    added to the list or not. But it works.
    An error from the terminal programs like lynx shouldn't crash
    tut.
    When you are reading a thread tut won't make unnecessary API
    requests
  * add history to help
  * 1.0.19 (#179)
  * 1.0.18 (#175)
  * Updating go install command. (#167)
  * 1.0.17 (#164)
  * 1.0.16 (#161)
  * 1.0.15 (#160)
  * 1.0.14 (#159)
  * 1.0.13 (#157)
* Mon Nov 21 2022 Stefan Weiberg <sweiberg@suse.com>
- Initial packaging of tut version 1.0.19:
  * New features:
    New command :history and leader action history that lets you
    see the edit history of a toot.
    Notifications when someone edits a toot you've boosted.
  * Bug fix
    An error from the editor shouldn't crash tut.
